from flask import Flask
from flask_sqlalchemy import SQLAlchemy
from flask_wtf.csrf import CSRFProtect


db = SQLAlchemy()
csrf = CSRFProtect()


def create_app():
    app = Flask(__name__, instance_relative_config=True)
    app.jinja_env.add_extension('pypugjs.ext.jinja.PyPugJSExtension')
    app.config.from_pyfile('config.py')

    db.init_app(app)
    # Ignore linter error unused export: we need to import the models to
    # register them with SQLAlchemy
    from . import models  # noqa: F401
    with app.app_context():
        db.create_all()

    csrf.init_app(app)

    from . import views
    app.register_blueprint(views.bp)

    return app
